@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef RECIPIENTSEDITORMANAGER_H
-#define RECIPIENTSEDITORMANAGER_H
+#pragma once
 
 #include "akonadi-contact_export.h"
 #include <QObject>
@@ -32,4 +31,3 @@ private:
 };
 }
 
-#endif // RECIPIENTSEDITORMANAGER_H
